"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.video.v1.thumbnail_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    page_size: builtins.int
    """The maximum number of the results per page to return. Default value: 100."""
    page_token: builtins.str
    """Page token for getting the next page of the result."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListThumbnailRequest = ListThumbnailRequest

@typing.final
class ListThumbnailResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAILS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page."""
    @property
    def thumbnails(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail]:
        """List of thumbnails."""

    def __init__(
        self,
        *,
        thumbnails: collections.abc.Iterable[yandex.cloud.video.v1.thumbnail_pb2.Thumbnail] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "thumbnails", b"thumbnails"]) -> None: ...

global___ListThumbnailResponse = ListThumbnailResponse

@typing.final
class CreateThumbnailRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id"]) -> None: ...

global___CreateThumbnailRequest = CreateThumbnailRequest

@typing.final
class CreateThumbnailMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___CreateThumbnailMetadata = CreateThumbnailMetadata

@typing.final
class BatchGenerateDownloadURLsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHANNEL_ID_FIELD_NUMBER: builtins.int
    THUMBNAIL_IDS_FIELD_NUMBER: builtins.int
    channel_id: builtins.str
    """ID of the channel."""
    @property
    def thumbnail_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of thumbnails IDs."""

    def __init__(
        self,
        *,
        channel_id: builtins.str = ...,
        thumbnail_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel_id", b"channel_id", "thumbnail_ids", b"thumbnail_ids"]) -> None: ...

global___BatchGenerateDownloadURLsRequest = BatchGenerateDownloadURLsRequest

@typing.final
class BatchGenerateDownloadURLsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOWNLOAD_URLS_FIELD_NUMBER: builtins.int
    @property
    def download_urls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ThumbnailDownloadURL]:
        """List of download urls."""

    def __init__(
        self,
        *,
        download_urls: collections.abc.Iterable[global___ThumbnailDownloadURL] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["download_urls", b"download_urls"]) -> None: ...

global___BatchGenerateDownloadURLsResponse = BatchGenerateDownloadURLsResponse

@typing.final
class ThumbnailDownloadURL(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    DOWNLOAD_URL_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    download_url: builtins.str
    """Download url."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
        download_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["download_url", b"download_url", "thumbnail_id", b"thumbnail_id"]) -> None: ...

global___ThumbnailDownloadURL = ThumbnailDownloadURL

@typing.final
class GenerateThumbnailUploadURLRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    def __init__(
        self,
        *,
        thumbnail_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["thumbnail_id", b"thumbnail_id"]) -> None: ...

global___GenerateThumbnailUploadURLRequest = GenerateThumbnailUploadURLRequest

@typing.final
class GenerateThumbnailUploadURLResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPLOAD_URL_FIELD_NUMBER: builtins.int
    upload_url: builtins.str
    """Upload url."""
    def __init__(
        self,
        *,
        upload_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["upload_url", b"upload_url"]) -> None: ...

global___GenerateThumbnailUploadURLResponse = GenerateThumbnailUploadURLResponse
