"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class KpiValue(google.protobuf.message.Message):
    """An actual value of test's KPI."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_ID_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    IS_OK_FIELD_NUMBER: builtins.int
    test_id: builtins.str
    """ID of a test."""
    value: builtins.float
    """Value of KPI."""
    is_ok: builtins.bool
    """A flag indicating whether the value satisfies KPI threshold condition."""
    def __init__(
        self,
        *,
        test_id: builtins.str = ...,
        value: builtins.float = ...,
        is_ok: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["is_ok", b"is_ok", "test_id", b"test_id", "value", b"value"]) -> None: ...

global___KpiValue = KpiValue
