# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.certificatemanager.v1 import certificate_pb2 as yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/certificatemanager/v1/certificate_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\x34yandex/cloud/certificatemanager/v1/certificate.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x80\x01\n\x15GetCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateView\"\xc1\x01\n\x17ListCertificatesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x41\n\x04view\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateViewJ\x04\x08\x04\x10\x06\"z\n\x18ListCertificatesResponse\x12\x45\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32/.yandex.cloud.certificatemanager.v1.Certificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x13ListVersionsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x14ListVersionsResponse\x12=\n\x08versions\x18\x01 \x03(\x0b\x32+.yandex.cloud.certificatemanager.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x03\n\x18\x43reateCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x95\x01\n\x06labels\x18\x04 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12 \n\x0b\x63\x65rtificate\x18\x05 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x06 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12%\n\x0bprivate_key\x18\x07 \x01(\tB\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08\x31-524288\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19\x43reateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x8d\x04\n\x18UpdateCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x95\x01\n\x06labels\x18\x05 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12 \n\x0b\x63\x65rtificate\x18\x06 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x07 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12!\n\x0bprivate_key\x18\x08 \x01(\tB\x0c\x8a\xc8\x31\x08<=524288\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19UpdateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"@\n\x18\x44\x65leteCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xd8\x03\n\x1cRequestNewCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x99\x01\n\x06labels\x18\x04 \x03(\x0b\x32L.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x0f\n\x07\x64omains\x18\x05 \x03(\t\x12I\n\x0e\x63hallenge_type\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.certificatemanager.v1.ChallengeType\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x1dRequestNewCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x86\x01\n ListCertificateOperationsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListCertificateOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*&\n\x0f\x43\x65rtificateView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\xca\x12\n\x12\x43\x65rtificateService\x12\xb0\x01\n\x03Get\x12\x39.yandex.cloud.certificatemanager.v1.GetCertificateRequest\x1a/.yandex.cloud.certificatemanager.v1.Certificate\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/certificate-manager/v1/certificates/{certificate_id}\x12\xaf\x01\n\x04List\x12;.yandex.cloud.certificatemanager.v1.ListCertificatesRequest\x1a<.yandex.cloud.certificatemanager.v1.ListCertificatesResponse\",\x82\xd3\xe4\x93\x02&\x12$/certificate-manager/v1/certificates\x12\xc9\x01\n\x0cListVersions\x12\x37.yandex.cloud.certificatemanager.v1.ListVersionsRequest\x1a\x38.yandex.cloud.certificatemanager.v1.ListVersionsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/certificate-manager/v1/certificates/{certificate_id}/versions\x12\xc6\x01\n\x06\x43reate\x12<.yandex.cloud.certificatemanager.v1.CreateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*(\n\x19\x43reateCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02)\"$/certificate-manager/v1/certificates:\x01*\x12\xd7\x01\n\x06Update\x12<.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*(\n\x19UpdateCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02:25/certificate-manager/v1/certificates/{certificate_id}:\x01*\x12\xd4\x01\n\x06\x44\x65lete\x12<.yandex.cloud.certificatemanager.v1.DeleteCertificateRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*(\n\x19\x44\x65leteCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02\x37*5/certificate-manager/v1/certificates/{certificate_id}\x12\xdd\x01\n\nRequestNew\x12@.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*,\n\x1dRequestNewCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02\x34\"//certificate-manager/v1/certificates/requestNew:\x01*\x12\xe7\x01\n\x0eListOperations\x12\x44.yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest\x1a\x45.yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}/operations\x12\xc4\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/certificate-manager/v1/certificates/{resource_id}:listAccessBindings\x12\xf4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\x01*\x12\x80\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\x01*B\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.certificatemanager.v1.certificate_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager'
  _GETCERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
  _GETCERTIFICATEREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCERTIFICATESREQUEST.fields_by_name['folder_id']._options = None
  _LISTCERTIFICATESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCERTIFICATESREQUEST.fields_by_name['page_size']._options = None
  _LISTCERTIFICATESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCERTIFICATESREQUEST.fields_by_name['page_token']._options = None
  _LISTCERTIFICATESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTVERSIONSREQUEST.fields_by_name['certificate_id']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATECERTIFICATEREQUEST_LABELSENTRY._options = None
  _CREATECERTIFICATEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECERTIFICATEREQUEST.fields_by_name['name']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATECERTIFICATEREQUEST.fields_by_name['description']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _CREATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['certificate']._serialized_options = b'\212\3101\007<=32768'
  _CREATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['chain']._serialized_options = b'\212\3101\t<=2097152'
  _CREATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['private_key']._serialized_options = b'\350\3071\001\212\3101\0101-524288'
  _UPDATECERTIFICATEREQUEST_LABELSENTRY._options = None
  _UPDATECERTIFICATEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECERTIFICATEREQUEST.fields_by_name['name']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATECERTIFICATEREQUEST.fields_by_name['description']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _UPDATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate']._serialized_options = b'\212\3101\007<=32768'
  _UPDATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['chain']._serialized_options = b'\212\3101\t<=2097152'
  _UPDATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['private_key']._serialized_options = b'\212\3101\010<=524288'
  _DELETECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
  _DELETECERTIFICATEREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY._options = None
  _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['name']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['description']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['certificate_id']._options = None
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CERTIFICATESERVICE.methods_by_name['Get']._options = None
  _CERTIFICATESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0027\0225/certificate-manager/v1/certificates/{certificate_id}'
  _CERTIFICATESERVICE.methods_by_name['List']._options = None
  _CERTIFICATESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002&\022$/certificate-manager/v1/certificates'
  _CERTIFICATESERVICE.methods_by_name['ListVersions']._options = None
  _CERTIFICATESERVICE.methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002@\022>/certificate-manager/v1/certificates/{certificate_id}/versions'
  _CERTIFICATESERVICE.methods_by_name['Create']._options = None
  _CERTIFICATESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateCertificateMetadata\022\013Certificate\202\323\344\223\002)\"$/certificate-manager/v1/certificates:\001*'
  _CERTIFICATESERVICE.methods_by_name['Update']._options = None
  _CERTIFICATESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateCertificateMetadata\022\013Certificate\202\323\344\223\002:25/certificate-manager/v1/certificates/{certificate_id}:\001*'
  _CERTIFICATESERVICE.methods_by_name['Delete']._options = None
  _CERTIFICATESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*(\n\031DeleteCertificateMetadata\022\013Certificate\202\323\344\223\0027*5/certificate-manager/v1/certificates/{certificate_id}'
  _CERTIFICATESERVICE.methods_by_name['RequestNew']._options = None
  _CERTIFICATESERVICE.methods_by_name['RequestNew']._serialized_options = b'\262\322*,\n\035RequestNewCertificateMetadata\022\013Certificate\202\323\344\223\0024\"//certificate-manager/v1/certificates/requestNew:\001*'
  _CERTIFICATESERVICE.methods_by_name['ListOperations']._options = None
  _CERTIFICATESERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}/operations'
  _CERTIFICATESERVICE.methods_by_name['ListAccessBindings']._options = None
  _CERTIFICATESERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002G\022E/certificate-manager/v1/certificates/{resource_id}:listAccessBindings'
  _CERTIFICATESERVICE.methods_by_name['SetAccessBindings']._options = None
  _CERTIFICATESERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\001*'
  _CERTIFICATESERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _CERTIFICATESERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\001*'
  _globals['_CERTIFICATEVIEW']._serialized_start=3060
  _globals['_CERTIFICATEVIEW']._serialized_end=3098
  _globals['_GETCERTIFICATEREQUEST']._serialized_start=358
  _globals['_GETCERTIFICATEREQUEST']._serialized_end=486
  _globals['_LISTCERTIFICATESREQUEST']._serialized_start=489
  _globals['_LISTCERTIFICATESREQUEST']._serialized_end=682
  _globals['_LISTCERTIFICATESRESPONSE']._serialized_start=684
  _globals['_LISTCERTIFICATESRESPONSE']._serialized_end=806
  _globals['_LISTVERSIONSREQUEST']._serialized_start=808
  _globals['_LISTVERSIONSREQUEST']._serialized_end=929
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=931
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=1041
  _globals['_CREATECERTIFICATEREQUEST']._serialized_start=1044
  _globals['_CREATECERTIFICATEREQUEST']._serialized_end=1519
  _globals['_CREATECERTIFICATEREQUEST_LABELSENTRY']._serialized_start=1474
  _globals['_CREATECERTIFICATEREQUEST_LABELSENTRY']._serialized_end=1519
  _globals['_CREATECERTIFICATEMETADATA']._serialized_start=1521
  _globals['_CREATECERTIFICATEMETADATA']._serialized_end=1572
  _globals['_UPDATECERTIFICATEREQUEST']._serialized_start=1575
  _globals['_UPDATECERTIFICATEREQUEST']._serialized_end=2100
  _globals['_UPDATECERTIFICATEREQUEST_LABELSENTRY']._serialized_start=1474
  _globals['_UPDATECERTIFICATEREQUEST_LABELSENTRY']._serialized_end=1519
  _globals['_UPDATECERTIFICATEMETADATA']._serialized_start=2102
  _globals['_UPDATECERTIFICATEMETADATA']._serialized_end=2153
  _globals['_DELETECERTIFICATEREQUEST']._serialized_start=2155
  _globals['_DELETECERTIFICATEREQUEST']._serialized_end=2219
  _globals['_DELETECERTIFICATEMETADATA']._serialized_start=2221
  _globals['_DELETECERTIFICATEMETADATA']._serialized_end=2272
  _globals['_REQUESTNEWCERTIFICATEREQUEST']._serialized_start=2275
  _globals['_REQUESTNEWCERTIFICATEREQUEST']._serialized_end=2747
  _globals['_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY']._serialized_start=1474
  _globals['_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY']._serialized_end=1519
  _globals['_REQUESTNEWCERTIFICATEMETADATA']._serialized_start=2749
  _globals['_REQUESTNEWCERTIFICATEMETADATA']._serialized_end=2804
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST']._serialized_start=2807
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST']._serialized_end=2941
  _globals['_LISTCERTIFICATEOPERATIONSRESPONSE']._serialized_start=2943
  _globals['_LISTCERTIFICATEOPERATIONSRESPONSE']._serialized_end=3058
  _globals['_CERTIFICATESERVICE']._serialized_start=3101
  _globals['_CERTIFICATESERVICE']._serialized_end=5479
# @@protoc_insertion_point(module_scope)
