# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/containers/v1/container.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/serverless/containers/v1/container.proto\x12%yandex.cloud.serverless.containers.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xab\x03\n\tContainer\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12L\n\x06labels\x18\x06 \x03(\x0b\x32<.yandex.cloud.serverless.containers.v1.Container.LabelsEntry\x12\x0b\n\x03url\x18\x08 \x01(\t\x12G\n\x06status\x18\t \x01(\x0e\x32\x37.yandex.cloud.serverless.containers.v1.Container.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"S\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\t\n\x05\x45RROR\x10\x04J\x04\x08\x07\x10\x08\"\xac\x07\n\x08Revision\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x63ontainer_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x05image\x18\x05 \x01(\x0b\x32,.yandex.cloud.serverless.containers.v1.Image\x12\x43\n\tresources\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.serverless.containers.v1.Resources\x12\x34\n\x11\x65xecution_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x13\n\x0b\x63oncurrency\x18\x08 \x01(\x03\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x46\n\x06status\x18\n \x01(\x0e\x32\x36.yandex.cloud.serverless.containers.v1.Revision.Status\x12>\n\x07secrets\x18\x0b \x03(\x0b\x32-.yandex.cloud.serverless.containers.v1.Secret\x12I\n\x0c\x63onnectivity\x18\x0c \x01(\x0b\x32\x33.yandex.cloud.serverless.containers.v1.Connectivity\x12P\n\x10provision_policy\x18\r \x01(\x0b\x32\x36.yandex.cloud.serverless.containers.v1.ProvisionPolicy\x12L\n\x0escaling_policy\x18\x0e \x01(\x0b\x32\x34.yandex.cloud.serverless.containers.v1.ScalingPolicy\x12\x46\n\x0blog_options\x18\x0f \x01(\x0b\x32\x31.yandex.cloud.serverless.containers.v1.LogOptions\x12K\n\x0estorage_mounts\x18\x10 \x03(\x0b\x32\x33.yandex.cloud.serverless.containers.v1.StorageMount\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08OBSOLETE\x10\x03\"\xf0\x02\n\x05Image\x12\x11\n\timage_url\x18\x01 \x01(\t\x12\x14\n\x0cimage_digest\x18\x02 \x01(\t\x12?\n\x07\x63ommand\x18\x03 \x01(\x0b\x32..yandex.cloud.serverless.containers.v1.Command\x12\x39\n\x04\x61rgs\x18\x04 \x01(\x0b\x32+.yandex.cloud.serverless.containers.v1.Args\x12y\n\x0b\x65nvironment\x18\x05 \x03(\x0b\x32=.yandex.cloud.serverless.containers.v1.Image.EnvironmentEntryB%\x8a\xc8\x31\x06<=4096\xb2\xc8\x31\x17\x12\x15[a-zA-Z][a-zA-Z0-9_]*\x12\x13\n\x0bworking_dir\x18\x06 \x01(\t\x1a\x32\n\x10\x45nvironmentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1a\n\x07\x43ommand\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\"\x14\n\x04\x41rgs\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\"o\n\tResources\x12(\n\x06memory\x18\x01 \x01(\x03\x42\x18\xfa\xc7\x31\x14\x31\x33\x34\x32\x31\x37\x37\x32\x38-4294967296\x12\x16\n\x05\x63ores\x18\x02 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x30-2\x12 \n\rcore_fraction\x18\x03 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\"(\n\x0fProvisionPolicy\x12\x15\n\rmin_instances\x18\x01 \x01(\x03\"b\n\x06Secret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nversion_id\x18\x02 \x01(\t\x12\x0b\n\x03key\x18\x03 \x01(\t\x12\x1e\n\x14\x65nvironment_variable\x18\x04 \x01(\tH\x00\x42\x0b\n\treference\"B\n\x0c\x43onnectivity\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x1e\n\nsubnet_ids\x18\x02 \x03(\tB\n\x8a\xc8\x31\x02>0\x90\xc8\x31\x01\"\xe0\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12;\n\x0clog_group_id\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12\x38\n\tfolder_id\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f([a-zA-Z][-a-zA-Z0-9_.]{0,63})?H\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\"J\n\rScalingPolicy\x12\x1c\n\x14zone_instances_limit\x18\x01 \x01(\x03\x12\x1b\n\x13zone_requests_limit\x18\x02 \x01(\x03\"\xa6\x01\n\x0cStorageMount\x12\x31\n\tbucket_id\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[-.0-9a-zA-Z]*\x8a\xc8\x31\x04\x33-63\x12\x0e\n\x06prefix\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x04 \x01(\x08\x12:\n\x10mount_point_path\x18\x05 \x01(\tB \xe8\xc7\x31\x01\xf2\xc7\x31\x0f[-_0-9a-zA-Z/]*\x8a\xc8\x31\x05\x31-300J\x04\x08\x03\x10\x04\x42\x81\x01\n)yandex.cloud.api.serverless.containers.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/containers/v1;containersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.containers.v1.container_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.serverless.containers.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/containers/v1;containers'
  _CONTAINER_LABELSENTRY._options = None
  _CONTAINER_LABELSENTRY._serialized_options = b'8\001'
  _IMAGE_ENVIRONMENTENTRY._options = None
  _IMAGE_ENVIRONMENTENTRY._serialized_options = b'8\001'
  _IMAGE.fields_by_name['environment']._options = None
  _IMAGE.fields_by_name['environment']._serialized_options = b'\212\3101\006<=4096\262\3101\027\022\025[a-zA-Z][a-zA-Z0-9_]*'
  _RESOURCES.fields_by_name['memory']._options = None
  _RESOURCES.fields_by_name['memory']._serialized_options = b'\372\3071\024134217728-4294967296'
  _RESOURCES.fields_by_name['cores']._options = None
  _RESOURCES.fields_by_name['cores']._serialized_options = b'\372\3071\0030-2'
  _RESOURCES.fields_by_name['core_fraction']._options = None
  _RESOURCES.fields_by_name['core_fraction']._serialized_options = b'\372\3071\0050-100'
  _CONNECTIVITY.fields_by_name['subnet_ids']._options = None
  _CONNECTIVITY.fields_by_name['subnet_ids']._serialized_options = b'\212\3101\002>0\220\3101\001'
  _LOGOPTIONS.fields_by_name['log_group_id']._options = None
  _LOGOPTIONS.fields_by_name['log_group_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _LOGOPTIONS.fields_by_name['folder_id']._options = None
  _LOGOPTIONS.fields_by_name['folder_id']._serialized_options = b'\362\3071\037([a-zA-Z][-a-zA-Z0-9_.]{0,63})?'
  _STORAGEMOUNT.fields_by_name['bucket_id']._options = None
  _STORAGEMOUNT.fields_by_name['bucket_id']._serialized_options = b'\350\3071\001\362\3071\016[-.0-9a-zA-Z]*\212\3101\0043-63'
  _STORAGEMOUNT.fields_by_name['mount_point_path']._options = None
  _STORAGEMOUNT.fields_by_name['mount_point_path']._serialized_options = b'\350\3071\001\362\3071\017[-_0-9a-zA-Z/]*\212\3101\0051-300'
  _globals['_CONTAINER']._serialized_start=234
  _globals['_CONTAINER']._serialized_end=661
  _globals['_CONTAINER_LABELSENTRY']._serialized_start=525
  _globals['_CONTAINER_LABELSENTRY']._serialized_end=570
  _globals['_CONTAINER_STATUS']._serialized_start=572
  _globals['_CONTAINER_STATUS']._serialized_end=655
  _globals['_REVISION']._serialized_start=664
  _globals['_REVISION']._serialized_end=1604
  _globals['_REVISION_STATUS']._serialized_start=1532
  _globals['_REVISION_STATUS']._serialized_end=1604
  _globals['_IMAGE']._serialized_start=1607
  _globals['_IMAGE']._serialized_end=1975
  _globals['_IMAGE_ENVIRONMENTENTRY']._serialized_start=1925
  _globals['_IMAGE_ENVIRONMENTENTRY']._serialized_end=1975
  _globals['_COMMAND']._serialized_start=1977
  _globals['_COMMAND']._serialized_end=2003
  _globals['_ARGS']._serialized_start=2005
  _globals['_ARGS']._serialized_end=2025
  _globals['_RESOURCES']._serialized_start=2027
  _globals['_RESOURCES']._serialized_end=2138
  _globals['_PROVISIONPOLICY']._serialized_start=2140
  _globals['_PROVISIONPOLICY']._serialized_end=2180
  _globals['_SECRET']._serialized_start=2182
  _globals['_SECRET']._serialized_end=2280
  _globals['_CONNECTIVITY']._serialized_start=2282
  _globals['_CONNECTIVITY']._serialized_end=2348
  _globals['_LOGOPTIONS']._serialized_start=2351
  _globals['_LOGOPTIONS']._serialized_end=2575
  _globals['_SCALINGPOLICY']._serialized_start=2577
  _globals['_SCALINGPOLICY']._serialized_end=2651
  _globals['_STORAGEMOUNT']._serialized_start=2654
  _globals['_STORAGEMOUNT']._serialized_end=2820
# @@protoc_insertion_point(module_scope)
