# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/manager/v1/manager_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/dataproc/manager/v1/manager_service.proto\x12 yandex.cloud.dataproc.manager.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"_\n\rHbaseNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08requests\x18\x02 \x01(\x03\x12\x14\n\x0cheap_size_mb\x18\x03 \x01(\x03\x12\x18\n\x10max_heap_size_mb\x18\x04 \x01(\x03\"\xe1\x01\n\tHbaseInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x0f\n\x07regions\x18\x02 \x01(\x03\x12\x10\n\x08requests\x18\x03 \x01(\x03\x12\x14\n\x0c\x61verage_load\x18\x04 \x01(\x01\x12\x43\n\nlive_nodes\x18\x05 \x03(\x0b\x32/.yandex.cloud.dataproc.manager.v1.HbaseNodeInfo\x12\x43\n\ndead_nodes\x18\x06 \x03(\x0b\x32/.yandex.cloud.dataproc.manager.v1.HbaseNodeInfo\"r\n\x0cHDFSNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04used\x18\x02 \x01(\x03\x12\x11\n\tremaining\x18\x03 \x01(\x03\x12\x10\n\x08\x63\x61pacity\x18\x04 \x01(\x03\x12\x12\n\nnum_blocks\x18\x05 \x01(\x03\x12\r\n\x05state\x18\x06 \x01(\t\"\x89\x04\n\x08HDFSInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x19\n\x11percent_remaining\x18\x02 \x01(\x01\x12\x0c\n\x04used\x18\x03 \x01(\x03\x12\x0c\n\x04\x66ree\x18\x04 \x01(\x03\x12\x14\n\x0ctotal_blocks\x18\x05 \x01(\x03\x12\x16\n\x0emissing_blocks\x18\x06 \x01(\x03\x12\"\n\x1amissing_blocks_replica_one\x18\x07 \x01(\x03\x12\x42\n\nlive_nodes\x18\x08 \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12\x42\n\ndead_nodes\x18\t \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12\x10\n\x08safemode\x18\x0b \x01(\t\x12M\n\x15\x64\x65\x63ommissioning_nodes\x18\x0c \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12L\n\x14\x64\x65\x63ommissioned_nodes\x18\r \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.HDFSNodeInfo\x12$\n\x1crequested_decommission_hosts\x18\x0e \x03(\tJ\x04\x08\n\x10\x0b\"\x9b\x01\n\x08HiveInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x19\n\x11queries_succeeded\x18\x02 \x01(\x03\x12\x16\n\x0equeries_failed\x18\x03 \x01(\x03\x12\x19\n\x11queries_executing\x18\x04 \x01(\x03\x12\x15\n\rsessions_open\x18\x05 \x01(\x03\x12\x17\n\x0fsessions_active\x18\x06 \x01(\x03\"\x8d\x01\n\x0cYarnNodeInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12\x16\n\x0enum_containers\x18\x03 \x01(\x03\x12\x16\n\x0eused_memory_mb\x18\x04 \x01(\x03\x12\x1b\n\x13\x61vailable_memory_mb\x18\x05 \x01(\x03\x12\x13\n\x0bupdate_time\x18\x06 \x01(\x03\"\x87\x01\n\x08YarnInfo\x12\x11\n\tavailable\x18\x01 \x01(\x08\x12\x42\n\nlive_nodes\x18\x02 \x03(\x0b\x32..yandex.cloud.dataproc.manager.v1.YarnNodeInfo\x12$\n\x1crequested_decommission_hosts\x18\x03 \x03(\t\"\x1e\n\rZookeeperInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\x1a\n\tOozieInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"\x19\n\x08LivyInfo\x12\r\n\x05\x61live\x18\x01 \x01(\x08\"Y\n\x08InitActs\x12>\n\x05state\x18\x01 \x01(\x0e\x32/.yandex.cloud.dataproc.manager.v1.InitActsState\x12\r\n\x05\x66qdns\x18\x02 \x03(\t\"\xff\x03\n\x04Info\x12\x38\n\x04hdfs\x18\x01 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.HDFSInfo\x12\x38\n\x04yarn\x18\x02 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.YarnInfo\x12\x38\n\x04hive\x18\x03 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.HiveInfo\x12\x42\n\tzookeeper\x18\x04 \x01(\x0b\x32/.yandex.cloud.dataproc.manager.v1.ZookeeperInfo\x12:\n\x05hbase\x18\x05 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.HbaseInfo\x12:\n\x05oozie\x18\x06 \x01(\x0b\x32+.yandex.cloud.dataproc.manager.v1.OozieInfo\x12\x14\n\x0creport_count\x18\x07 \x01(\x03\x12\x38\n\x04livy\x18\x08 \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.LivyInfo\x12=\n\tinit_acts\x18\t \x01(\x0b\x32*.yandex.cloud.dataproc.manager.v1.InitActs\"\x9f\x01\n\rReportRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x19\n\x11topology_revision\x18\x02 \x01(\x03\x12\x34\n\x04info\x18\x03 \x01(\x0b\x32&.yandex.cloud.dataproc.manager.v1.Info\x12\x30\n\x0c\x63ollected_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"s\n\x0bReportReply\x12\x1c\n\x14\x64\x65\x63ommission_timeout\x18\x01 \x01(\x03\x12\"\n\x1ayarn_hosts_to_decommission\x18\x02 \x03(\t\x12\"\n\x1ahdfs_hosts_to_decommission\x18\x03 \x03(\t*]\n\rInitActsState\x12\x1f\n\x1bINIT_ACTS_STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0e\n\nSUCCESSFUL\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x32\x84\x01\n\x16\x44\x61taprocManagerService\x12j\n\x06Report\x12/.yandex.cloud.dataproc.manager.v1.ReportRequest\x1a-.yandex.cloud.dataproc.manager.v1.ReportReply\"\x00\x42}\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_managerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.manager.v1.manager_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$yandex.cloud.api.dataproc.manager.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/manager/v1;dataproc_manager'
  _globals['_INITACTSSTATE']._serialized_start=2501
  _globals['_INITACTSSTATE']._serialized_end=2594
  _globals['_HBASENODEINFO']._serialized_start=125
  _globals['_HBASENODEINFO']._serialized_end=220
  _globals['_HBASEINFO']._serialized_start=223
  _globals['_HBASEINFO']._serialized_end=448
  _globals['_HDFSNODEINFO']._serialized_start=450
  _globals['_HDFSNODEINFO']._serialized_end=564
  _globals['_HDFSINFO']._serialized_start=567
  _globals['_HDFSINFO']._serialized_end=1088
  _globals['_HIVEINFO']._serialized_start=1091
  _globals['_HIVEINFO']._serialized_end=1246
  _globals['_YARNNODEINFO']._serialized_start=1249
  _globals['_YARNNODEINFO']._serialized_end=1390
  _globals['_YARNINFO']._serialized_start=1393
  _globals['_YARNINFO']._serialized_end=1528
  _globals['_ZOOKEEPERINFO']._serialized_start=1530
  _globals['_ZOOKEEPERINFO']._serialized_end=1560
  _globals['_OOZIEINFO']._serialized_start=1562
  _globals['_OOZIEINFO']._serialized_end=1588
  _globals['_LIVYINFO']._serialized_start=1590
  _globals['_LIVYINFO']._serialized_end=1615
  _globals['_INITACTS']._serialized_start=1617
  _globals['_INITACTS']._serialized_end=1706
  _globals['_INFO']._serialized_start=1709
  _globals['_INFO']._serialized_end=2220
  _globals['_REPORTREQUEST']._serialized_start=2223
  _globals['_REPORTREQUEST']._serialized_end=2382
  _globals['_REPORTREPLY']._serialized_start=2384
  _globals['_REPORTREPLY']._serialized_end=2499
  _globals['_DATAPROCMANAGERSERVICE']._serialized_start=2597
  _globals['_DATAPROCMANAGERSERVICE']._serialized_end=2729
# @@protoc_insertion_point(module_scope)
