# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/ip_permission.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/containerregistry/v1/ip_permission.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\"\x98\x01\n\x0cIpPermission\x12\x46\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x36.yandex.cloud.containerregistry.v1.IpPermission.Action\x12\n\n\x02ip\x18\x02 \x01(\t\"4\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x08\n\x04PULL\x10\x01\x12\x08\n\x04PUSH\x10\x02\"\xae\x01\n\x11IpPermissionDelta\x12K\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x35.yandex.cloud.containerregistry.v1.IpPermissionActionB\x04\xe8\xc7\x31\x01\x12L\n\rip_permission\x18\x02 \x01(\x0b\x32/.yandex.cloud.containerregistry.v1.IpPermissionB\x04\xe8\xc7\x31\x01*O\n\x12IpPermissionAction\x12$\n IP_PERMISSION_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.ip_permission_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _IPPERMISSIONDELTA.fields_by_name['action']._options = None
  _IPPERMISSIONDELTA.fields_by_name['action']._serialized_options = b'\350\3071\001'
  _IPPERMISSIONDELTA.fields_by_name['ip_permission']._options = None
  _IPPERMISSIONDELTA.fields_by_name['ip_permission']._serialized_options = b'\350\3071\001'
  _globals['_IPPERMISSIONACTION']._serialized_start=455
  _globals['_IPPERMISSIONACTION']._serialized_end=534
  _globals['_IPPERMISSION']._serialized_start=124
  _globals['_IPPERMISSION']._serialized_end=276
  _globals['_IPPERMISSION_ACTION']._serialized_start=224
  _globals['_IPPERMISSION_ACTION']._serialized_end=276
  _globals['_IPPERMISSIONDELTA']._serialized_start=279
  _globals['_IPPERMISSIONDELTA']._serialized_end=453
# @@protoc_insertion_point(module_scope)
