"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ImbalancePoint(google.protobuf.message.Message):
    """Test imbalance point."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AT_FIELD_NUMBER: builtins.int
    RPS_FIELD_NUMBER: builtins.int
    rps: builtins.int
    """Imbalance moment RPS."""
    @property
    def at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Imbalance moment timestamp."""

    def __init__(
        self,
        *,
        at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        rps: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["at", b"at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["at", b"at", "rps", b"rps"]) -> None: ...

global___ImbalancePoint = ImbalancePoint
