"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ImageCopySearchAnnotation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COPY_COUNT_FIELD_NUMBER: builtins.int
    TOP_RESULTS_FIELD_NUMBER: builtins.int
    copy_count: builtins.int
    """Number of image copies"""
    @property
    def top_results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CopyMatch]:
        """Top relevance result of image copy search"""

    def __init__(
        self,
        *,
        copy_count: builtins.int = ...,
        top_results: collections.abc.Iterable[global___CopyMatch] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["copy_count", b"copy_count", "top_results", b"top_results"]) -> None: ...

global___ImageCopySearchAnnotation = ImageCopySearchAnnotation

@typing.final
class CopyMatch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_URL_FIELD_NUMBER: builtins.int
    PAGE_URL_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    image_url: builtins.str
    """url of image"""
    page_url: builtins.str
    """url of page that contains image"""
    title: builtins.str
    """page title that contains image"""
    description: builtins.str
    """image description"""
    def __init__(
        self,
        *,
        image_url: builtins.str = ...,
        page_url: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "image_url", b"image_url", "page_url", b"page_url", "title", b"title"]) -> None: ...

global___CopyMatch = CopyMatch
