"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.lockbox.v1.payload_pb2
import yandex.cloud.lockbox.v1.payload_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class PayloadServiceStub:
    """Set of methods to access payload of secrets."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.payload_service_pb2.GetPayloadRequest,
        yandex.cloud.lockbox.v1.payload_pb2.Payload,
    ]
    """Returns the payload of the specified secret.

    To get the list of all available secrets, make a [SecretService.List] request.
    """

class PayloadServiceAsyncStub:
    """Set of methods to access payload of secrets."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.lockbox.v1.payload_service_pb2.GetPayloadRequest,
        yandex.cloud.lockbox.v1.payload_pb2.Payload,
    ]
    """Returns the payload of the specified secret.

    To get the list of all available secrets, make a [SecretService.List] request.
    """

class PayloadServiceServicer(metaclass=abc.ABCMeta):
    """Set of methods to access payload of secrets."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.lockbox.v1.payload_service_pb2.GetPayloadRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.lockbox.v1.payload_pb2.Payload, collections.abc.Awaitable[yandex.cloud.lockbox.v1.payload_pb2.Payload]]:
        """Returns the payload of the specified secret.

        To get the list of all available secrets, make a [SecretService.List] request.
        """

def add_PayloadServiceServicer_to_server(servicer: PayloadServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
