"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Status:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Status.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATUS_UNSPECIFIED: _Status.ValueType  # 0
    """Status is not specified."""
    PREPARING_TEST: _Status.ValueType  # 1
    """Agent is preparing a test to be executed."""
    READY_FOR_TEST: _Status.ValueType  # 2
    """Agent is ready to take a test."""
    TESTING: _Status.ValueType  # 3
    """Agent is executing a test."""
    TANK_FAILED: _Status.ValueType  # 4
    """Agent application encountered an error and cannot operate normally."""
    PROVISIONING: _Status.ValueType  # 5
    """Agent is waiting for resources to be allocated."""
    STOPPING: _Status.ValueType  # 6
    """Agent is being stopped."""
    STOPPED: _Status.ValueType  # 7
    """Agent is stopped."""
    STARTING: _Status.ValueType  # 8
    """Agent is being started."""
    RESTARTING: _Status.ValueType  # 9
    """Agent is being restarted."""
    UPDATING: _Status.ValueType  # 10
    """Agent is being updated."""
    ERROR: _Status.ValueType  # 11
    """Agent encountered an error and cannot operate."""
    CRASHED: _Status.ValueType  # 12
    """Agent is crashed and will be restarted automatically."""
    DELETING: _Status.ValueType  # 13
    """Agent is being deleted."""
    INITIALIZING_CONNECTION: _Status.ValueType  # 15
    """Service is waiting for connection with agent to be established."""
    LOST_CONNECTION_WITH_AGENT: _Status.ValueType  # 16
    """Service has lost connection with agent."""
    UPLOADING_ARTIFACTS: _Status.ValueType  # 17
    """Agent is uploading test artifacts."""

class Status(_Status, metaclass=_StatusEnumTypeWrapper):
    """Agent status."""

STATUS_UNSPECIFIED: Status.ValueType  # 0
"""Status is not specified."""
PREPARING_TEST: Status.ValueType  # 1
"""Agent is preparing a test to be executed."""
READY_FOR_TEST: Status.ValueType  # 2
"""Agent is ready to take a test."""
TESTING: Status.ValueType  # 3
"""Agent is executing a test."""
TANK_FAILED: Status.ValueType  # 4
"""Agent application encountered an error and cannot operate normally."""
PROVISIONING: Status.ValueType  # 5
"""Agent is waiting for resources to be allocated."""
STOPPING: Status.ValueType  # 6
"""Agent is being stopped."""
STOPPED: Status.ValueType  # 7
"""Agent is stopped."""
STARTING: Status.ValueType  # 8
"""Agent is being started."""
RESTARTING: Status.ValueType  # 9
"""Agent is being restarted."""
UPDATING: Status.ValueType  # 10
"""Agent is being updated."""
ERROR: Status.ValueType  # 11
"""Agent encountered an error and cannot operate."""
CRASHED: Status.ValueType  # 12
"""Agent is crashed and will be restarted automatically."""
DELETING: Status.ValueType  # 13
"""Agent is being deleted."""
INITIALIZING_CONNECTION: Status.ValueType  # 15
"""Service is waiting for connection with agent to be established."""
LOST_CONNECTION_WITH_AGENT: Status.ValueType  # 16
"""Service has lost connection with agent."""
UPLOADING_ARTIFACTS: Status.ValueType  # 17
"""Agent is uploading test artifacts."""
global___Status = Status
