# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/bucket_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.storage.v1 import bucket_pb2 as yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/storage/v1/bucket_service.proto\x12\x17yandex.cloud.storage.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a$yandex/cloud/storage/v1/bucket.proto\x1a\x1dyandex/cloud/validation.proto\"\xaf\x01\n\x10GetBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x04view\x18\x02 \x01(\x0e\x32..yandex.cloud.storage.v1.GetBucketRequest.View\"I\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\x0c\n\x08VIEW_ACL\x10\x02\x12\r\n\tVIEW_FULL\x10\x03\"5\n\x12ListBucketsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"G\n\x13ListBucketsResponse\x12\x30\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.storage.v1.Bucket\"\xa7\x02\n\x13\x43reateBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x04 \x01(\t\x12\x10\n\x08max_size\x18\x05 \x01(\x03\x12M\n\x16\x61nonymous_access_flags\x18\x06 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12)\n\x03\x61\x63l\x18\x07 \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12*\n\x04tags\x18\x08 \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.TagJ\x04\x08\x03\x10\x04\"$\n\x14\x43reateBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc2\x05\n\x13UpdateBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12M\n\x16\x61nonymous_access_flags\x18\x03 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x04 \x01(\t\x12\x10\n\x08max_size\x18\x05 \x01(\x03\x12/\n\x04\x63ors\x18\x06 \x03(\x0b\x32!.yandex.cloud.storage.v1.CorsRule\x12\x42\n\x10website_settings\x18\x07 \x01(\x0b\x32(.yandex.cloud.storage.v1.WebsiteSettings\x12\x37\n\nversioning\x18\x08 \x01(\x0e\x32#.yandex.cloud.storage.v1.Versioning\x12?\n\x0flifecycle_rules\x18\t \x03(\x0b\x32&.yandex.cloud.storage.v1.LifecycleRule\x12\'\n\x06policy\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x03\x61\x63l\x18\x0b \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12*\n\x04tags\x18\x0c \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12\x38\n\x0bobject_lock\x18\r \x01(\x0b\x32#.yandex.cloud.storage.v1.ObjectLock\x12\x37\n\nencryption\x18\x0e \x01(\x0b\x32#.yandex.cloud.storage.v1.Encryption\"$\n\x14UpdateBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\")\n\x13\x44\x65leteBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"$\n\x14\x44\x65leteBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x15GetBucketStatsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x1bGetBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"n\n\x1cSelfManagedHTTPSConfigParams\x12&\n\x0f\x63\x65rtificate_pem\x18\x01 \x01(\tB\r\x8a\xc8\x31\t<=3145728\x12&\n\x0fprivate_key_pem\x18\x02 \x01(\tB\r\x8a\xc8\x31\t<=3145728\"=\n#CertificateManagerHTTPSConfigParams\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xed\x01\n\x1bSetBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12M\n\x0cself_managed\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.storage.v1.SelfManagedHTTPSConfigParamsH\x00\x12[\n\x13\x63\x65rtificate_manager\x18\x03 \x01(\x0b\x32<.yandex.cloud.storage.v1.CertificateManagerHTTPSConfigParamsH\x00\x42\x0e\n\x06params\x12\x04\xc0\xc1\x31\x01\",\n\x1cSetBucketHTTPSConfigMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"4\n\x1e\x44\x65leteBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x1f\x44\x65leteBucketHTTPSConfigMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t2\xe1\x0b\n\rBucketService\x12~\n\x04List\x12+.yandex.cloud.storage.v1.ListBucketsRequest\x1a,.yandex.cloud.storage.v1.ListBucketsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/storage/v1/buckets\x12u\n\x03Get\x12).yandex.cloud.storage.v1.GetBucketRequest\x1a\x1f.yandex.cloud.storage.v1.Bucket\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/storage/v1/buckets/{name}\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.storage.v1.CreateBucketRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reateBucketMetadata\x12\x06\x42ucket\x82\xd3\xe4\x93\x02\x18\"\x13/storage/v1/buckets:\x01*\x12\xa2\x01\n\x06Update\x12,.yandex.cloud.storage.v1.UpdateBucketRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x1e\n\x14UpdateBucketMetadata\x12\x06\x42ucket\x82\xd3\xe4\x93\x02\x1f\x32\x1a/storage/v1/buckets/{name}:\x01*\x12\xae\x01\n\x06\x44\x65lete\x12,.yandex.cloud.storage.v1.DeleteBucketRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*-\n\x14\x44\x65leteBucketMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1c*\x1a/storage/v1/buckets/{name}\x12\x8d\x01\n\x08GetStats\x12..yandex.cloud.storage.v1.GetBucketStatsRequest\x1a$.yandex.cloud.storage.v1.BucketStats\"+\x82\xd3\xe4\x93\x02%\x12#/storage/v1/buckets/{name}:getStats\x12\x9f\x01\n\x0eGetHTTPSConfig\x12\x34.yandex.cloud.storage.v1.GetBucketHTTPSConfigRequest\x1a$.yandex.cloud.storage.v1.HTTPSConfig\"1\x82\xd3\xe4\x93\x02+\x12)/storage/v1/buckets/{name}:getHttpsConfig\x12\xce\x01\n\x0eSetHTTPSConfig\x12\x34.yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*+\n\x1cSetBucketHTTPSConfigMetadata\x12\x0bHTTPSConfig\x82\xd3\xe4\x93\x02.\")/storage/v1/buckets/{name}:setHttpsConfig:\x01*\x12\xe1\x01\n\x11\x44\x65leteHTTPSConfig\x12\x37.yandex.cloud.storage.v1.DeleteBucketHTTPSConfigRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*8\n\x1f\x44\x65leteBucketHTTPSConfigMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.\",/storage/v1/buckets/{name}:deleteHttpsConfigBb\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.bucket_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _GETBUCKETREQUEST.fields_by_name['name']._options = None
  _GETBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _LISTBUCKETSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBUCKETSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEBUCKETREQUEST.fields_by_name['name']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CREATEBUCKETREQUEST.fields_by_name['folder_id']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEBUCKETREQUEST.fields_by_name['name']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _UPDATEBUCKETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _DELETEBUCKETREQUEST.fields_by_name['name']._options = None
  _DELETEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _GETBUCKETSTATSREQUEST.fields_by_name['name']._options = None
  _GETBUCKETSTATSREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _GETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
  _GETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['certificate_pem']._options = None
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['certificate_pem']._serialized_options = b'\212\3101\t<=3145728'
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['private_key_pem']._options = None
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['private_key_pem']._serialized_options = b'\212\3101\t<=3145728'
  _SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']._options = None
  _SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']._serialized_options = b'\300\3011\001'
  _SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
  _SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _DELETEBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
  _DELETEBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _BUCKETSERVICE.methods_by_name['List']._options = None
  _BUCKETSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/storage/v1/buckets'
  _BUCKETSERVICE.methods_by_name['Get']._options = None
  _BUCKETSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/storage/v1/buckets/{name}'
  _BUCKETSERVICE.methods_by_name['Create']._options = None
  _BUCKETSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateBucketMetadata\022\006Bucket\202\323\344\223\002\030\"\023/storage/v1/buckets:\001*'
  _BUCKETSERVICE.methods_by_name['Update']._options = None
  _BUCKETSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateBucketMetadata\022\006Bucket\202\323\344\223\002\0372\032/storage/v1/buckets/{name}:\001*'
  _BUCKETSERVICE.methods_by_name['Delete']._options = None
  _BUCKETSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBucketMetadata\022\025google.protobuf.Empty\202\323\344\223\002\034*\032/storage/v1/buckets/{name}'
  _BUCKETSERVICE.methods_by_name['GetStats']._options = None
  _BUCKETSERVICE.methods_by_name['GetStats']._serialized_options = b'\202\323\344\223\002%\022#/storage/v1/buckets/{name}:getStats'
  _BUCKETSERVICE.methods_by_name['GetHTTPSConfig']._options = None
  _BUCKETSERVICE.methods_by_name['GetHTTPSConfig']._serialized_options = b'\202\323\344\223\002+\022)/storage/v1/buckets/{name}:getHttpsConfig'
  _BUCKETSERVICE.methods_by_name['SetHTTPSConfig']._options = None
  _BUCKETSERVICE.methods_by_name['SetHTTPSConfig']._serialized_options = b'\262\322*+\n\034SetBucketHTTPSConfigMetadata\022\013HTTPSConfig\202\323\344\223\002.\")/storage/v1/buckets/{name}:setHttpsConfig:\001*'
  _BUCKETSERVICE.methods_by_name['DeleteHTTPSConfig']._options = None
  _BUCKETSERVICE.methods_by_name['DeleteHTTPSConfig']._serialized_options = b'\262\322*8\n\037DeleteBucketHTTPSConfigMetadata\022\025google.protobuf.Empty\202\323\344\223\002.\",/storage/v1/buckets/{name}:deleteHttpsConfig'
  _globals['_GETBUCKETREQUEST']._serialized_start=311
  _globals['_GETBUCKETREQUEST']._serialized_end=486
  _globals['_GETBUCKETREQUEST_VIEW']._serialized_start=413
  _globals['_GETBUCKETREQUEST_VIEW']._serialized_end=486
  _globals['_LISTBUCKETSREQUEST']._serialized_start=488
  _globals['_LISTBUCKETSREQUEST']._serialized_end=541
  _globals['_LISTBUCKETSRESPONSE']._serialized_start=543
  _globals['_LISTBUCKETSRESPONSE']._serialized_end=614
  _globals['_CREATEBUCKETREQUEST']._serialized_start=617
  _globals['_CREATEBUCKETREQUEST']._serialized_end=912
  _globals['_CREATEBUCKETMETADATA']._serialized_start=914
  _globals['_CREATEBUCKETMETADATA']._serialized_end=950
  _globals['_UPDATEBUCKETREQUEST']._serialized_start=953
  _globals['_UPDATEBUCKETREQUEST']._serialized_end=1659
  _globals['_UPDATEBUCKETMETADATA']._serialized_start=1661
  _globals['_UPDATEBUCKETMETADATA']._serialized_end=1697
  _globals['_DELETEBUCKETREQUEST']._serialized_start=1699
  _globals['_DELETEBUCKETREQUEST']._serialized_end=1740
  _globals['_DELETEBUCKETMETADATA']._serialized_start=1742
  _globals['_DELETEBUCKETMETADATA']._serialized_end=1778
  _globals['_GETBUCKETSTATSREQUEST']._serialized_start=1780
  _globals['_GETBUCKETSTATSREQUEST']._serialized_end=1823
  _globals['_GETBUCKETHTTPSCONFIGREQUEST']._serialized_start=1825
  _globals['_GETBUCKETHTTPSCONFIGREQUEST']._serialized_end=1874
  _globals['_SELFMANAGEDHTTPSCONFIGPARAMS']._serialized_start=1876
  _globals['_SELFMANAGEDHTTPSCONFIGPARAMS']._serialized_end=1986
  _globals['_CERTIFICATEMANAGERHTTPSCONFIGPARAMS']._serialized_start=1988
  _globals['_CERTIFICATEMANAGERHTTPSCONFIGPARAMS']._serialized_end=2049
  _globals['_SETBUCKETHTTPSCONFIGREQUEST']._serialized_start=2052
  _globals['_SETBUCKETHTTPSCONFIGREQUEST']._serialized_end=2289
  _globals['_SETBUCKETHTTPSCONFIGMETADATA']._serialized_start=2291
  _globals['_SETBUCKETHTTPSCONFIGMETADATA']._serialized_end=2335
  _globals['_DELETEBUCKETHTTPSCONFIGREQUEST']._serialized_start=2337
  _globals['_DELETEBUCKETHTTPSCONFIGREQUEST']._serialized_end=2389
  _globals['_DELETEBUCKETHTTPSCONFIGMETADATA']._serialized_start=2391
  _globals['_DELETEBUCKETHTTPSCONFIGMETADATA']._serialized_end=2438
  _globals['_BUCKETSERVICE']._serialized_start=2441
  _globals['_BUCKETSERVICE']._serialized_end=3946
# @@protoc_insertion_point(module_scope)
