# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import database_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ydb/v1/database_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\"yandex/cloud/ydb/v1/database.proto\x1a yandex/cloud/ydb/v1/backup.proto\"e\n\x13MoveDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x14MoveDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\x89\x01\n\x14RestoreBackupRequest\x12\x1f\n\tbackup_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x64\x61tabase_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10paths_to_restore\x18\x03 \x03(\t\x12\x13\n\x0btarget_path\x18\x04 \x01(\t\"?\n\x15RestoreBackupMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\"j\n\x15\x42\x61\x63kupDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12<\n\x0f\x62\x61\x63kup_settings\x18\x02 \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\"@\n\x16\x42\x61\x63kupDatabaseMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\"9\n\x14StartDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x15StartDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"8\n\x13StopDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x14StopDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"7\n\x12GetDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"g\n\x14ListDatabasesRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListDatabasesResponse\x12\x30\n\tdatabases\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.ydb.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe6\x06\n\x15\x43reateDatabaseRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\x04 \x01(\t\x12:\n\x0estorage_config\x18\x05 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x12\n\nsubnet_ids\x18\x08 \x03(\t\x12<\n\x0ezonal_database\x18\t \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\n \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\r \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x0e \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\x0b \x01(\x08\x12\x13\n\x0blocation_id\x18\x0c \x01(\t\x12\x46\n\x06labels\x18\x0f \x03(\x0b\x32\x36.yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry\x12\x38\n\rbackup_config\x18\x10 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12@\n\x11monitoring_config\x18\x11 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x12 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rdatabase_type\"D\n\x16\x43reateDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\xac\x07\n\x15UpdateDatabaseRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0b\x64\x61tabase_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\x06 \x01(\t\x12:\n\x0estorage_config\x18\x07 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x08 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\t \x01(\t\x12\x12\n\nsubnet_ids\x18\n \x03(\t\x12<\n\x0ezonal_database\x18\x0b \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\x0c \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\x0f \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x10 \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\r \x01(\x08\x12\x13\n\x0blocation_id\x18\x0e \x01(\t\x12\x46\n\x06labels\x18\x11 \x03(\x0b\x32\x36.yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry\x12\x38\n\rbackup_config\x18\x12 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12@\n\x11monitoring_config\x18\x13 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rdatabase_type\"D\n\x16UpdateDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\",\n\x15\x44\x65leteDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\"D\n\x16\x44\x65leteDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\x9a\x10\n\x0f\x44\x61tabaseService\x12v\n\x03Get\x12\'.yandex.cloud.ydb.v1.GetDatabaseRequest\x1a\x1d.yandex.cloud.ydb.v1.Database\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/ydb/v1/databases/{database_id}\x12x\n\x04List\x12).yandex.cloud.ydb.v1.ListDatabasesRequest\x1a*.yandex.cloud.ydb.v1.ListDatabasesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/ydb/v1/databases\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.ydb.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"B\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x16\"\x11/ydb/v1/databases:\x01*\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.ydb.v1.UpdateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\"\n\x16UpdateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02$2\x1f/ydb/v1/databases/{database_id}:\x01*\x12\xa9\x01\n\x05Start\x12).yandex.cloud.ydb.v1.StartDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*!\n\x15StartDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\'\"%/ydb/v1/databases/{database_id}:start\x12\xa5\x01\n\x04Stop\x12(.yandex.cloud.ydb.v1.StopDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2* \n\x14StopDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02&\"$/ydb/v1/databases/{database_id}:stop\x12\xa8\x01\n\x04Move\x12(.yandex.cloud.ydb.v1.MoveDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x14MoveDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02)\"$/ydb/v1/databases/{database_id}:move:\x01*\x12u\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\x12\xa4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xad\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.ydb.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/ydb/v1/databases/{database_id}\x12\xa2\x01\n\x07Restore\x12).yandex.cloud.ydb.v1.RestoreBackupRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*!\n\x15RestoreBackupMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x1e\"\x19/ydb/v1/databases:restore:\x01*\x12\xa2\x01\n\x06\x42\x61\x63kup\x12*.yandex.cloud.ydb.v1.BackupDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*\"\n\x16\x42\x61\x63kupDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x1d\"\x18/ydb/v1/databases:backup:\x01*BV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.database_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _MOVEDATABASEREQUEST.fields_by_name['database_id']._options = None
  _MOVEDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEDATABASEREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEDATABASEREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTOREBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _RESTOREBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTOREBACKUPREQUEST.fields_by_name['database_id']._options = None
  _RESTOREBACKUPREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTDATABASEREQUEST.fields_by_name['database_id']._options = None
  _STARTDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPDATABASEREQUEST.fields_by_name['database_id']._options = None
  _STOPDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETDATABASEREQUEST.fields_by_name['database_id']._options = None
  _GETDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEDATABASEREQUEST_LABELSENTRY._options = None
  _CREATEDATABASEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEDATABASEREQUEST_LABELSENTRY._options = None
  _UPDATEDATABASEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATABASESERVICE.methods_by_name['Get']._options = None
  _DATABASESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/ydb/v1/databases/{database_id}'
  _DATABASESERVICE.methods_by_name['List']._options = None
  _DATABASESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/ydb/v1/databases'
  _DATABASESERVICE.methods_by_name['Create']._options = None
  _DATABASESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateDatabaseMetadata\022\010Database\202\323\344\223\002\026\"\021/ydb/v1/databases:\001*'
  _DATABASESERVICE.methods_by_name['Update']._options = None
  _DATABASESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateDatabaseMetadata\022\010Database\202\323\344\223\002$2\037/ydb/v1/databases/{database_id}:\001*'
  _DATABASESERVICE.methods_by_name['Start']._options = None
  _DATABASESERVICE.methods_by_name['Start']._serialized_options = b'\262\322*!\n\025StartDatabaseMetadata\022\010Database\202\323\344\223\002\'\"%/ydb/v1/databases/{database_id}:start'
  _DATABASESERVICE.methods_by_name['Stop']._options = None
  _DATABASESERVICE.methods_by_name['Stop']._serialized_options = b'\262\322* \n\024StopDatabaseMetadata\022\010Database\202\323\344\223\002&\"$/ydb/v1/databases/{database_id}:stop'
  _DATABASESERVICE.methods_by_name['Move']._options = None
  _DATABASESERVICE.methods_by_name['Move']._serialized_options = b'\262\322* \n\024MoveDatabaseMetadata\022\010Database\202\323\344\223\002)\"$/ydb/v1/databases/{database_id}:move:\001*'
  _DATABASESERVICE.methods_by_name['SetAccessBindings']._options = None
  _DATABASESERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty'
  _DATABASESERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _DATABASESERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty'
  _DATABASESERVICE.methods_by_name['Delete']._options = None
  _DATABASESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/ydb/v1/databases/{database_id}'
  _DATABASESERVICE.methods_by_name['Restore']._options = None
  _DATABASESERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*!\n\025RestoreBackupMetadata\022\010Database\202\323\344\223\002\036\"\031/ydb/v1/databases:restore:\001*'
  _DATABASESERVICE.methods_by_name['Backup']._options = None
  _DATABASESERVICE.methods_by_name['Backup']._serialized_options = b'\262\322*\"\n\026BackupDatabaseMetadata\022\010Database\202\323\344\223\002\035\"\030/ydb/v1/databases:backup:\001*'
  _globals['_MOVEDATABASEREQUEST']._serialized_start=340
  _globals['_MOVEDATABASEREQUEST']._serialized_end=441
  _globals['_MOVEDATABASEMETADATA']._serialized_start=443
  _globals['_MOVEDATABASEMETADATA']._serialized_end=509
  _globals['_RESTOREBACKUPREQUEST']._serialized_start=512
  _globals['_RESTOREBACKUPREQUEST']._serialized_end=649
  _globals['_RESTOREBACKUPMETADATA']._serialized_start=651
  _globals['_RESTOREBACKUPMETADATA']._serialized_end=714
  _globals['_BACKUPDATABASEREQUEST']._serialized_start=716
  _globals['_BACKUPDATABASEREQUEST']._serialized_end=822
  _globals['_BACKUPDATABASEMETADATA']._serialized_start=824
  _globals['_BACKUPDATABASEMETADATA']._serialized_end=888
  _globals['_STARTDATABASEREQUEST']._serialized_start=890
  _globals['_STARTDATABASEREQUEST']._serialized_end=947
  _globals['_STARTDATABASEMETADATA']._serialized_start=949
  _globals['_STARTDATABASEMETADATA']._serialized_end=1016
  _globals['_STOPDATABASEREQUEST']._serialized_start=1018
  _globals['_STOPDATABASEREQUEST']._serialized_end=1074
  _globals['_STOPDATABASEMETADATA']._serialized_start=1076
  _globals['_STOPDATABASEMETADATA']._serialized_end=1142
  _globals['_GETDATABASEREQUEST']._serialized_start=1144
  _globals['_GETDATABASEREQUEST']._serialized_end=1199
  _globals['_LISTDATABASESREQUEST']._serialized_start=1201
  _globals['_LISTDATABASESREQUEST']._serialized_end=1304
  _globals['_LISTDATABASESRESPONSE']._serialized_start=1306
  _globals['_LISTDATABASESRESPONSE']._serialized_end=1404
  _globals['_CREATEDATABASEREQUEST']._serialized_start=1407
  _globals['_CREATEDATABASEREQUEST']._serialized_end=2277
  _globals['_CREATEDATABASEREQUEST_LABELSENTRY']._serialized_start=2215
  _globals['_CREATEDATABASEREQUEST_LABELSENTRY']._serialized_end=2260
  _globals['_CREATEDATABASEMETADATA']._serialized_start=2279
  _globals['_CREATEDATABASEMETADATA']._serialized_end=2347
  _globals['_UPDATEDATABASEREQUEST']._serialized_start=2350
  _globals['_UPDATEDATABASEREQUEST']._serialized_end=3290
  _globals['_UPDATEDATABASEREQUEST_LABELSENTRY']._serialized_start=2215
  _globals['_UPDATEDATABASEREQUEST_LABELSENTRY']._serialized_end=2260
  _globals['_UPDATEDATABASEMETADATA']._serialized_start=3292
  _globals['_UPDATEDATABASEMETADATA']._serialized_end=3360
  _globals['_DELETEDATABASEREQUEST']._serialized_start=3362
  _globals['_DELETEDATABASEREQUEST']._serialized_end=3406
  _globals['_DELETEDATABASEMETADATA']._serialized_start=3408
  _globals['_DELETEDATABASEMETADATA']._serialized_end=3476
  _globals['_DATABASESERVICE']._serialized_start=3479
  _globals['_DATABASESERVICE']._serialized_end=5553
# @@protoc_insertion_point(module_scope)
