# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/security_profile_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartwebsecurity.v1 import security_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_security__profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/smartwebsecurity/v1/security_profile_service.proto\x12 yandex.cloud.smartwebsecurity.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x37yandex/cloud/smartwebsecurity/v1/security_profile.proto\">\n\x19GetSecurityProfileRequest\x12!\n\x13security_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1bListSecurityProfilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"l\n\x1cListSecurityProfilesResponse\x12L\n\x11security_profiles\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.smartwebsecurity.v1.SecurityProfile\"\x9a\x03\n\x1c\x43reateSecurityProfileRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12Z\n\x06labels\x18\x02 \x03(\x0b\x32J.yandex.cloud.smartwebsecurity.v1.CreateSecurityProfileRequest.LabelsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12W\n\x0e\x64\x65\x66\x61ult_action\x18\x05 \x01(\x0e\x32?.yandex.cloud.smartwebsecurity.v1.SecurityProfile.DefaultAction\x12\x46\n\x0esecurity_rules\x18\x06 \x03(\x0b\x32..yandex.cloud.smartwebsecurity.v1.SecurityRule\x12\x12\n\ncaptcha_id\x18\x07 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x1d\x43reateSecurityProfileMetadata\x12\x1b\n\x13security_profile_id\x18\x01 \x01(\t\"\xd5\x03\n\x1cUpdateSecurityProfileRequest\x12!\n\x13security_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12Z\n\x06labels\x18\x03 \x03(\x0b\x32J.yandex.cloud.smartwebsecurity.v1.UpdateSecurityProfileRequest.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12W\n\x0e\x64\x65\x66\x61ult_action\x18\x06 \x01(\x0e\x32?.yandex.cloud.smartwebsecurity.v1.SecurityProfile.DefaultAction\x12\x46\n\x0esecurity_rules\x18\x07 \x03(\x0b\x32..yandex.cloud.smartwebsecurity.v1.SecurityRule\x12\x12\n\ncaptcha_id\x18\x08 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x1dUpdateSecurityProfileMetadata\x12\x1b\n\x13security_profile_id\x18\x01 \x01(\t\"A\n\x1c\x44\x65leteSecurityProfileRequest\x12!\n\x13security_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"<\n\x1d\x44\x65leteSecurityProfileMetadata\x12\x1b\n\x13security_profile_id\x18\x01 \x01(\t2\xb7\x08\n\x16SecurityProfileService\x12\xba\x01\n\x03Get\x12;.yandex.cloud.smartwebsecurity.v1.GetSecurityProfileRequest\x1a\x31.yandex.cloud.smartwebsecurity.v1.SecurityProfile\"C\x82\xd3\xe4\x93\x02=\x12;/smartwebsecurity/v1/securityProfiles/{security_profile_id}\x12\xb4\x01\n\x04List\x12=.yandex.cloud.smartwebsecurity.v1.ListSecurityProfilesRequest\x1a>.yandex.cloud.smartwebsecurity.v1.ListSecurityProfilesResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/smartwebsecurity/v1/securityProfiles\x12\xd1\x01\n\x06\x43reate\x12>.yandex.cloud.smartwebsecurity.v1.CreateSecurityProfileRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*0\n\x1d\x43reateSecurityProfileMetadata\x12\x0fSecurityProfile\x82\xd3\xe4\x93\x02*\"%/smartwebsecurity/v1/securityProfiles:\x01*\x12\xe7\x01\n\x06Update\x12>.yandex.cloud.smartwebsecurity.v1.UpdateSecurityProfileRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*0\n\x1dUpdateSecurityProfileMetadata\x12\x0fSecurityProfile\x82\xd3\xe4\x93\x02@2;/smartwebsecurity/v1/securityProfiles/{security_profile_id}:\x01*\x12\xea\x01\n\x06\x44\x65lete\x12>.yandex.cloud.smartwebsecurity.v1.DeleteSecurityProfileRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*6\n\x1d\x44\x65leteSecurityProfileMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/smartwebsecurity/v1/securityProfiles/{security_profile_id}B}\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.security_profile_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurity'
  _GETSECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._options = None
  _GETSECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._serialized_options = b'\350\3071\001'
  _LISTSECURITYPROFILESREQUEST.fields_by_name['folder_id']._options = None
  _LISTSECURITYPROFILESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATESECURITYPROFILEREQUEST_LABELSENTRY._options = None
  _CREATESECURITYPROFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESECURITYPROFILEREQUEST.fields_by_name['folder_id']._options = None
  _CREATESECURITYPROFILEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _UPDATESECURITYPROFILEREQUEST_LABELSENTRY._options = None
  _UPDATESECURITYPROFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._options = None
  _UPDATESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._serialized_options = b'\350\3071\001'
  _DELETESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._options = None
  _DELETESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._serialized_options = b'\350\3071\001'
  _SECURITYPROFILESERVICE.methods_by_name['Get']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/smartwebsecurity/v1/securityProfiles/{security_profile_id}'
  _SECURITYPROFILESERVICE.methods_by_name['List']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\'\022%/smartwebsecurity/v1/securityProfiles'
  _SECURITYPROFILESERVICE.methods_by_name['Create']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateSecurityProfileMetadata\022\017SecurityProfile\202\323\344\223\002*\"%/smartwebsecurity/v1/securityProfiles:\001*'
  _SECURITYPROFILESERVICE.methods_by_name['Update']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateSecurityProfileMetadata\022\017SecurityProfile\202\323\344\223\002@2;/smartwebsecurity/v1/securityProfiles/{security_profile_id}:\001*'
  _SECURITYPROFILESERVICE.methods_by_name['Delete']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteSecurityProfileMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/smartwebsecurity/v1/securityProfiles/{security_profile_id}'
  _globals['_GETSECURITYPROFILEREQUEST']._serialized_start=327
  _globals['_GETSECURITYPROFILEREQUEST']._serialized_end=389
  _globals['_LISTSECURITYPROFILESREQUEST']._serialized_start=391
  _globals['_LISTSECURITYPROFILESREQUEST']._serialized_end=445
  _globals['_LISTSECURITYPROFILESRESPONSE']._serialized_start=447
  _globals['_LISTSECURITYPROFILESRESPONSE']._serialized_end=555
  _globals['_CREATESECURITYPROFILEREQUEST']._serialized_start=558
  _globals['_CREATESECURITYPROFILEREQUEST']._serialized_end=968
  _globals['_CREATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_start=923
  _globals['_CREATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_end=968
  _globals['_CREATESECURITYPROFILEMETADATA']._serialized_start=970
  _globals['_CREATESECURITYPROFILEMETADATA']._serialized_end=1030
  _globals['_UPDATESECURITYPROFILEREQUEST']._serialized_start=1033
  _globals['_UPDATESECURITYPROFILEREQUEST']._serialized_end=1502
  _globals['_UPDATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_start=923
  _globals['_UPDATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_end=968
  _globals['_UPDATESECURITYPROFILEMETADATA']._serialized_start=1504
  _globals['_UPDATESECURITYPROFILEMETADATA']._serialized_end=1564
  _globals['_DELETESECURITYPROFILEREQUEST']._serialized_start=1566
  _globals['_DELETESECURITYPROFILEREQUEST']._serialized_end=1631
  _globals['_DELETESECURITYPROFILEMETADATA']._serialized_start=1633
  _globals['_DELETESECURITYPROFILEMETADATA']._serialized_end=1693
  _globals['_SECURITYPROFILESERVICE']._serialized_start=1696
  _globals['_SECURITYPROFILESERVICE']._serialized_end=2775
# @@protoc_insertion_point(module_scope)
