# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/scanner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/containerregistry/v1/scanner.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1dyandex/cloud/validation.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb5\x02\n\nScanResult\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08image_id\x18\x02 \x01(\t\x12.\n\nscanned_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x06status\x18\x04 \x01(\x0e\x32\x34.yandex.cloud.containerregistry.v1.ScanResult.Status\x12N\n\x0fvulnerabilities\x18\x05 \x01(\x0b\x32\x35.yandex.cloud.containerregistry.v1.VulnerabilityStats\"C\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\t\n\x05READY\x10\x02\x12\t\n\x05\x45RROR\x10\x03\"x\n\x12VulnerabilityStats\x12\x10\n\x08\x63ritical\x18\x01 \x01(\x03\x12\x0c\n\x04high\x18\x02 \x01(\x03\x12\x0e\n\x06medium\x18\x03 \x01(\x03\x12\x0b\n\x03low\x18\x04 \x01(\x03\x12\x12\n\nnegligible\x18\x05 \x01(\x03\x12\x11\n\tundefined\x18\x06 \x01(\x03\"\xb1\x02\n\rVulnerability\x12K\n\x08severity\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.containerregistry.v1.Vulnerability.Severity\x12J\n\x07package\x18\x02 \x01(\x0b\x32\x37.yandex.cloud.containerregistry.v1.PackageVulnerabilityH\x00\"p\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\x08\n\x04HIGH\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x07\n\x03LOW\x10\x04\x12\x0e\n\nNEGLIGIBLE\x10\x05\x12\r\n\tUNDEFINED\x10\x06\x42\x15\n\rvulnerability\x12\x04\xc0\xc1\x31\x01\"\x94\x01\n\x14PackageVulnerability\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04link\x18\x02 \x01(\t\x12\x0f\n\x07package\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\t\x12\x10\n\x08\x66ixed_by\x18\x06 \x01(\t\x12\x0e\n\x06origin\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\tB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.scanner_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _VULNERABILITY.oneofs_by_name['vulnerability']._options = None
  _VULNERABILITY.oneofs_by_name['vulnerability']._serialized_options = b'\300\3011\001'
  _globals['_SCANRESULT']._serialized_start=151
  _globals['_SCANRESULT']._serialized_end=460
  _globals['_SCANRESULT_STATUS']._serialized_start=393
  _globals['_SCANRESULT_STATUS']._serialized_end=460
  _globals['_VULNERABILITYSTATS']._serialized_start=462
  _globals['_VULNERABILITYSTATS']._serialized_end=582
  _globals['_VULNERABILITY']._serialized_start=585
  _globals['_VULNERABILITY']._serialized_end=890
  _globals['_VULNERABILITY_SEVERITY']._serialized_start=755
  _globals['_VULNERABILITY_SEVERITY']._serialized_end=867
  _globals['_PACKAGEVULNERABILITY']._serialized_start=893
  _globals['_PACKAGEVULNERABILITY']._serialized_end=1041
# @@protoc_insertion_point(module_scope)
