"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.clickhouse.v1.format_schema_pb2
import yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class FormatSchemaServiceStub:
    """A set of methods for managing [format schemas](https://clickhouse.com/docs/en/interfaces/formats) for input and output data."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.GetFormatSchemaRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema,
    ]
    """Returns detailed information about a given format schema."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse,
    ]
    """Returns a list of format schemas in a cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.CreateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a format schema to a cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.UpdateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Changes a format schema."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.DeleteFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a format schema from a cluster."""

class FormatSchemaServiceAsyncStub:
    """A set of methods for managing [format schemas](https://clickhouse.com/docs/en/interfaces/formats) for input and output data."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.GetFormatSchemaRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema,
    ]
    """Returns detailed information about a given format schema."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasRequest,
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse,
    ]
    """Returns a list of format schemas in a cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.CreateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a format schema to a cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.UpdateFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Changes a format schema."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.DeleteFormatSchemaRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes a format schema from a cluster."""

class FormatSchemaServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing [format schemas](https://clickhouse.com/docs/en/interfaces/formats) for input and output data."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.GetFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.format_schema_pb2.FormatSchema]]:
        """Returns detailed information about a given format schema."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse, collections.abc.Awaitable[yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.ListFormatSchemasResponse]]:
        """Returns a list of format schemas in a cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.CreateFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a format schema to a cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.UpdateFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Changes a format schema."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.mdb.clickhouse.v1.format_schema_service_pb2.DeleteFormatSchemaRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes a format schema from a cluster."""

def add_FormatSchemaServiceServicer_to_server(servicer: FormatSchemaServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
