"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class AgentSelector(google.protobuf.message.Message):
    """Agent selection criterion.

    The structure is used by service to determine on which agents a specific test should be executed.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGENT_ID_FIELD_NUMBER: builtins.int
    MATCH_BY_FILTER_FIELD_NUMBER: builtins.int
    ANONYMOUS_AGENT_FIELD_NUMBER: builtins.int
    agent_id: builtins.str
    """Selection by agent ID."""
    match_by_filter: builtins.str
    """Selection by filter string."""
    anonymous_agent: builtins.bool
    """Select anonymoud (i.e. not registered) agents."""
    def __init__(
        self,
        *,
        agent_id: builtins.str = ...,
        match_by_filter: builtins.str = ...,
        anonymous_agent: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agent", b"agent", "agent_id", b"agent_id", "anonymous_agent", b"anonymous_agent", "match_by_filter", b"match_by_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent", b"agent", "agent_id", b"agent_id", "anonymous_agent", b"anonymous_agent", "match_by_filter", b"match_by_filter"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["agent", b"agent"]) -> typing.Literal["agent_id", "match_by_filter", "anonymous_agent"] | None: ...

global___AgentSelector = AgentSelector
