# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/foundation_models/v1/text_classification/text_classification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRyandex/cloud/ai/foundation_models/v1/text_classification/text_classification.proto\x12\x38yandex.cloud.ai.foundation_models.v1.text_classification\"8\n\x13\x43lassificationLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x01\"3\n\x14\x43lassificationSample\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\tB\xb0\x01\n<yandex.cloud.api.ai.foundation_models.v1.text_classificationZpgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_classification;text_classificationb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.foundation_models.v1.text_classification.text_classification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n<yandex.cloud.api.ai.foundation_models.v1.text_classificationZpgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/foundation_models/v1/text_classification;text_classification'
  _globals['_CLASSIFICATIONLABEL']._serialized_start=144
  _globals['_CLASSIFICATIONLABEL']._serialized_end=200
  _globals['_CLASSIFICATIONSAMPLE']._serialized_start=202
  _globals['_CLASSIFICATIONSAMPLE']._serialized_end=253
# @@protoc_insertion_point(module_scope)
