# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/elasticsearch/v1/extension_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.elasticsearch.v1 import extension_pb2 as yandex_dot_cloud_dot_mdb_dot_elasticsearch_dot_v1_dot_extension__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/mdb/elasticsearch/v1/extension_service.proto\x12!yandex.cloud.mdb.elasticsearch.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x31yandex/cloud/mdb/elasticsearch/v1/extension.proto\x1a&yandex/cloud/operation/operation.proto\"S\n\x13GetExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"w\n\x15ListExtensionsRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n\x16ListExtensionsResponse\x12@\n\nextensions\x18\x01 \x03(\x0b\x32,.yandex.cloud.mdb.elasticsearch.v1.Extension\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"V\n\x16\x44\x65leteExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"W\n\x17\x44\x65leteExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"f\n\x16UpdateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\"W\n\x17UpdateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"{\n\x16\x43reateExtensionRequest\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x11\n\x03uri\x18\x03 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x10\n\x08\x64isabled\x18\x04 \x01(\x08\"W\n\x17\x43reateExtensionMetadata\x12 \n\ncluster_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0c\x65xtension_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xc5\x08\n\x10\x45xtensionService\x12\xbe\x01\n\x03Get\x12\x36.yandex.cloud.mdb.elasticsearch.v1.GetExtensionRequest\x1a,.yandex.cloud.mdb.elasticsearch.v1.Extension\"Q\x82\xd3\xe4\x93\x02K\x12I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}\x12\xbf\x01\n\x04List\x12\x38.yandex.cloud.mdb.elasticsearch.v1.ListExtensionsRequest\x1a\x39.yandex.cloud.mdb.elasticsearch.v1.ListExtensionsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/managed-elasticsearch/v1/clusters/{cluster_id}/extensions\x12\xd5\x01\n\x06\x43reate\x12\x39.yandex.cloud.mdb.elasticsearch.v1.CreateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"m\xb2\xd2*$\n\x17\x43reateExtensionMetadata\x12\tExtension\x82\xd3\xe4\x93\x02?\":/managed-elasticsearch/v1/clusters/{cluster_id}/extensions:\x01*\x12\xe4\x01\n\x06Update\x12\x39.yandex.cloud.mdb.elasticsearch.v1.UpdateExtensionRequest\x1a!.yandex.cloud.operation.Operation\"|\xb2\xd2*$\n\x17UpdateExtensionMetadata\x12\tExtension\x82\xd3\xe4\x93\x02N2I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\x01*\x12\xee\x01\n\x06\x44\x65lete\x12\x39.yandex.cloud.mdb.elasticsearch.v1.DeleteExtensionRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*0\n\x17\x44\x65leteExtensionMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02K*I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}B|\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearchb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.elasticsearch.v1.extension_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.mdb.elasticsearch.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/elasticsearch/v1;elasticsearch'
  _GETEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
  _GETEXTENSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
  _GETEXTENSIONREQUEST.fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _LISTEXTENSIONSREQUEST.fields_by_name['cluster_id']._options = None
  _LISTEXTENSIONSREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTEXTENSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTEXTENSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTEXTENSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTEXTENSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _DELETEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
  _DELETEEXTENSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
  _DELETEEXTENSIONREQUEST.fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _DELETEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
  _DELETEEXTENSIONMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
  _DELETEEXTENSIONMETADATA.fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _UPDATEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
  _UPDATEEXTENSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEEXTENSIONREQUEST.fields_by_name['extension_id']._options = None
  _UPDATEEXTENSIONREQUEST.fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _UPDATEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
  _UPDATEEXTENSIONMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
  _UPDATEEXTENSIONMETADATA.fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _CREATEEXTENSIONREQUEST.fields_by_name['cluster_id']._options = None
  _CREATEEXTENSIONREQUEST.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEEXTENSIONREQUEST.fields_by_name['name']._options = None
  _CREATEEXTENSIONREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEEXTENSIONREQUEST.fields_by_name['uri']._options = None
  _CREATEEXTENSIONREQUEST.fields_by_name['uri']._serialized_options = b'\350\3071\001'
  _CREATEEXTENSIONMETADATA.fields_by_name['cluster_id']._options = None
  _CREATEEXTENSIONMETADATA.fields_by_name['cluster_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEEXTENSIONMETADATA.fields_by_name['extension_id']._options = None
  _CREATEEXTENSIONMETADATA.fields_by_name['extension_id']._serialized_options = b'\350\3071\001'
  _EXTENSIONSERVICE.methods_by_name['Get']._options = None
  _EXTENSIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002K\022I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}'
  _EXTENSIONSERVICE.methods_by_name['List']._options = None
  _EXTENSIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002<\022:/managed-elasticsearch/v1/clusters/{cluster_id}/extensions'
  _EXTENSIONSERVICE.methods_by_name['Create']._options = None
  _EXTENSIONSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*$\n\027CreateExtensionMetadata\022\tExtension\202\323\344\223\002?\":/managed-elasticsearch/v1/clusters/{cluster_id}/extensions:\001*'
  _EXTENSIONSERVICE.methods_by_name['Update']._options = None
  _EXTENSIONSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*$\n\027UpdateExtensionMetadata\022\tExtension\202\323\344\223\002N2I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}:\001*'
  _EXTENSIONSERVICE.methods_by_name['Delete']._options = None
  _EXTENSIONSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*0\n\027DeleteExtensionMetadata\022\025google.protobuf.Empty\202\323\344\223\002K*I/managed-elasticsearch/v1/clusters/{cluster_id}/extensions/{extension_id}'
  _globals['_GETEXTENSIONREQUEST']._serialized_start=282
  _globals['_GETEXTENSIONREQUEST']._serialized_end=365
  _globals['_LISTEXTENSIONSREQUEST']._serialized_start=367
  _globals['_LISTEXTENSIONSREQUEST']._serialized_end=486
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_start=488
  _globals['_LISTEXTENSIONSRESPONSE']._serialized_end=603
  _globals['_DELETEEXTENSIONREQUEST']._serialized_start=605
  _globals['_DELETEEXTENSIONREQUEST']._serialized_end=691
  _globals['_DELETEEXTENSIONMETADATA']._serialized_start=693
  _globals['_DELETEEXTENSIONMETADATA']._serialized_end=780
  _globals['_UPDATEEXTENSIONREQUEST']._serialized_start=782
  _globals['_UPDATEEXTENSIONREQUEST']._serialized_end=884
  _globals['_UPDATEEXTENSIONMETADATA']._serialized_start=886
  _globals['_UPDATEEXTENSIONMETADATA']._serialized_end=973
  _globals['_CREATEEXTENSIONREQUEST']._serialized_start=975
  _globals['_CREATEEXTENSIONREQUEST']._serialized_end=1098
  _globals['_CREATEEXTENSIONMETADATA']._serialized_start=1100
  _globals['_CREATEEXTENSIONMETADATA']._serialized_end=1187
  _globals['_EXTENSIONSERVICE']._serialized_start=1190
  _globals['_EXTENSIONSERVICE']._serialized_end=2283
# @@protoc_insertion_point(module_scope)
