"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class StorageType(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DEVICE_TYPE_FIELD_NUMBER: builtins.int
    REDUNDANCY_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    device_type: builtins.str
    redundancy_type: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        device_type: builtins.str = ...,
        redundancy_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["device_type", b"device_type", "id", b"id", "redundancy_type", b"redundancy_type"]) -> None: ...

global___StorageType = StorageType
