"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.dataproc.v1.subcluster_pb2
import yandex.cloud.dataproc.v1.subcluster_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SubclusterServiceStub:
    """A set of methods for managing Data Proc subclusters."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.GetSubclusterRequest,
        yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster,
    ]
    """Returns the specified subcluster.

    To get the list of all available subclusters, make a [SubclusterService.List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersRequest,
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse,
    ]
    """Retrieves a list of subclusters in the specified cluster."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.CreateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a subcluster in the specified cluster."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.UpdateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified subcluster."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.DeleteSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified subcluster."""

class SubclusterServiceAsyncStub:
    """A set of methods for managing Data Proc subclusters."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.GetSubclusterRequest,
        yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster,
    ]
    """Returns the specified subcluster.

    To get the list of all available subclusters, make a [SubclusterService.List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersRequest,
        yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse,
    ]
    """Retrieves a list of subclusters in the specified cluster."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.CreateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a subcluster in the specified cluster."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.UpdateSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified subcluster."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.dataproc.v1.subcluster_service_pb2.DeleteSubclusterRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified subcluster."""

class SubclusterServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Data Proc subclusters."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.GetSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster, collections.abc.Awaitable[yandex.cloud.dataproc.v1.subcluster_pb2.Subcluster]]:
        """Returns the specified subcluster.

        To get the list of all available subclusters, make a [SubclusterService.List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse, collections.abc.Awaitable[yandex.cloud.dataproc.v1.subcluster_service_pb2.ListSubclustersResponse]]:
        """Retrieves a list of subclusters in the specified cluster."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.CreateSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a subcluster in the specified cluster."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.UpdateSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified subcluster."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.dataproc.v1.subcluster_service_pb2.DeleteSubclusterRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified subcluster."""

def add_SubclusterServiceServicer_to_server(servicer: SubclusterServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
