"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SilenceStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOTAL_SIMULTANEOUS_SILENCE_DURATION_MS_FIELD_NUMBER: builtins.int
    TOTAL_SIMULTANEOUS_SILENCE_RATIO_FIELD_NUMBER: builtins.int
    SIMULTANEOUS_SILENCE_DURATION_ESTIMATION_FIELD_NUMBER: builtins.int
    TOTAL_SIMULTANEOUS_SILENCE_DURATION_SECONDS_FIELD_NUMBER: builtins.int
    total_simultaneous_silence_duration_ms: builtins.int
    total_simultaneous_silence_ratio: builtins.float
    """Simultaneous silence ratio within audio segment"""
    total_simultaneous_silence_duration_seconds: builtins.int
    @property
    def simultaneous_silence_duration_estimation(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics:
        """Descriptive statistics for simultaneous silence duration distribution"""

    def __init__(
        self,
        *,
        total_simultaneous_silence_duration_ms: builtins.int = ...,
        total_simultaneous_silence_ratio: builtins.float = ...,
        simultaneous_silence_duration_estimation: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.DescriptiveStatistics | None = ...,
        total_simultaneous_silence_duration_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["simultaneous_silence_duration_estimation", b"simultaneous_silence_duration_estimation"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["simultaneous_silence_duration_estimation", b"simultaneous_silence_duration_estimation", "total_simultaneous_silence_duration_ms", b"total_simultaneous_silence_duration_ms", "total_simultaneous_silence_duration_seconds", b"total_simultaneous_silence_duration_seconds", "total_simultaneous_silence_ratio", b"total_simultaneous_silence_ratio"]) -> None: ...

global___SilenceStatistics = SilenceStatistics
