"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.descriptor_pb2
import google.protobuf.internal.extension_dict
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class MapKeySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    PATTERN_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    value: builtins.str
    pattern: builtins.str
    length: builtins.str
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        pattern: builtins.str = ...,
        length: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["length", b"length", "pattern", b"pattern", "value", b"value"]) -> None: ...

global___MapKeySpec = MapKeySpec

EXACTLY_ONE_FIELD_NUMBER: builtins.int
REQUIRED_FIELD_NUMBER: builtins.int
PATTERN_FIELD_NUMBER: builtins.int
VALUE_FIELD_NUMBER: builtins.int
SIZE_FIELD_NUMBER: builtins.int
LENGTH_FIELD_NUMBER: builtins.int
UNIQUE_FIELD_NUMBER: builtins.int
MAP_KEY_FIELD_NUMBER: builtins.int
BYTES_FIELD_NUMBER: builtins.int
exactly_one: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.OneofOptions, builtins.bool]
required: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
pattern: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
value: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
size: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
length: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
unique: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.bool]
map_key: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, global___MapKeySpec]
bytes: google.protobuf.internal.extension_dict._ExtensionFieldDescriptor[google.protobuf.descriptor_pb2.FieldOptions, builtins.str]
