# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.test import agent_selector_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_agent__selector__pb2
from yandex.cloud.loadtesting.api.v1.test import file_pointer_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_file__pointer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEyandex/cloud/loadtesting/api/v1/test/single_agent_configuration.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x39yandex/cloud/loadtesting/api/v1/test/agent_selector.proto\x1a\x37yandex/cloud/loadtesting/api/v1/test/file_pointer.proto\"\xb5\x02\n\x18SingleAgentConfiguration\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12K\n\x0e\x61gent_selector\x18\x02 \x01(\x0b\x32\x33.yandex.cloud.loadtesting.api.v1.test.AgentSelector\x12X\n\x05\x66iles\x18\x03 \x03(\x0b\x32I.yandex.cloud.loadtesting.api.v1.test.SingleAgentConfiguration.FilesEntry\x1a_\n\nFilesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12@\n\x05value\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.loadtesting.api.v1.test.FilePointer:\x02\x38\x01\x42y\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.single_agent_configuration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _SINGLEAGENTCONFIGURATION_FILESENTRY._options = None
  _SINGLEAGENTCONFIGURATION_FILESENTRY._serialized_options = b'8\001'
  _globals['_SINGLEAGENTCONFIGURATION']._serialized_start=228
  _globals['_SINGLEAGENTCONFIGURATION']._serialized_end=537
  _globals['_SINGLEAGENTCONFIGURATION_FILESENTRY']._serialized_start=442
  _globals['_SINGLEAGENTCONFIGURATION_FILESENTRY']._serialized_end=537
# @@protoc_insertion_point(module_scope)
